/**
 * \addtogroup Crc_16
 * @{
 */

/*****************************************************************************/
/**
 * \file Crc_16.h
 * ISO3309 16-bit cyclic redundancy check calculation for the 8051 and
 * Keil C51.
 * \author Copyright (c) 2005, Murray R. Van Luyn. <vanluynm@iinet.net.au>
 * \version 0.1
 * \date 19-02-05
 */
/*****************************************************************************/

/*****************************************************************************
 *
 *     THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS
 *     OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 *     WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 *     ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
 *     DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 *     DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
 *     GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 *     INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 *     WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 *     NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 *     SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 ******************************************************************************/

#ifndef CRC_16_H
#define CRC_16_H


/*****************************************************************************
 *
 *                         Global Variable Declarations
 *
 *****************************************************************************/
extern code unsigned int crc_table[256];


/*****************************************************************************
 *
 *                              Macro Definitions
 *
 *****************************************************************************/

/** 
 * CRC 16-bit 'pass through' calculation macro.
 * The CRC checksum value must first be initialised with the hex value 0xFFFF.
 * A CRC value is then calculated for a block of data by passing each character
 * in turn through the CRC_16_PASS() macro to incrementally update the CRC value.
 * The resultant value is complemented to obtain the final checksum CRC code.
 * \param checksum the current CRC value as an \b unsigned \b int.
 * \param inData \b unsigned \b char to pass through CRC calculation.
 * \return The updated CRC value as an \b unsigned \b int.
 * \hideinitializer
 */
#define CRC_16_PASS(checksum, inData) \
          (((checksum) >> 8) ^ crc_table[ ((checksum) & 0xFF) ^ (inData) ])


#endif

/** @} */
